@@ -1,22 +1,4 @@
-# ##### BEGIN GPL LICENSE BLOCK #####
-#
-#  This program is free software; you can redistribute it and/or
-#  modify it under the terms of the GNU General Public License
-#  as published by the Free Software Foundation; either version 2
-#  of the License, or (at your option) any later version.
-#
-#  This program is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with this program; if not, write to the Free Software Foundation,
-#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-#
-# ##### END GPL LICENSE BLOCK #####
-
-# <pep8 compliant>
+# SPDX-License-Identifier: GPL-2.0-or-later
 
 """
 Even though this is in a package this can run as a stand alone scripts.
@@ -36,7 +18,6 @@ config = [
 
 import bpy
 import time
-import tempfile
 import os
 
 DEMO_CFG = "demo.py"
@@ -44,23 +25,26 @@ DEMO_CFG = "demo.py"
 # populate from script
 global_config_files = []
 
-global_config = dict(anim_cycles=1,
-                     anim_render=False,
-                     anim_screen_switch=0.0,
-                     anim_time_max=60.0,
-                     anim_time_min=4.0,
-                     mode='AUTO',
-                     display_render=4.0)
+global_config = dict(
+    anim_cycles=1,
+    anim_render=False,
+    anim_screen_switch=0.0,
+    anim_time_max=60.0,
+    anim_time_min=4.0,
+    mode='AUTO',
+    display_render=4.0,
+)
 
 # switch to the next file in 2 sec.
-global_config_fallback = dict(anim_cycles=1,
-                              anim_render=False,
-                              anim_screen_switch=0.0,
-                              anim_time_max=60.0,
-                              anim_time_min=4.0,
-                              mode='AUTO',
-                              display_render=4.0)
-
+global_config_fallback = dict(
+    anim_cycles=1,
+    anim_render=False,
+    anim_screen_switch=0.0,
+    anim_time_max=60.0,
+    anim_time_min=4.0,
+    mode='AUTO',
+    display_render=4.0,
+)
 
 global_state = {
     "init_time": 0.0,
@@ -154,7 +138,7 @@ def demo_mode_next_file(step=1):
 
 
 def demo_mode_timer_add():
-    global_state["timer"] = bpy.context.window_manager.event_timer_add(0.8, bpy.context.window)
+    global_state["timer"] = bpy.context.window_manager.event_timer_add(0.8, window=bpy.context.window)
 
 
 def demo_mode_timer_remove():
@@ -253,9 +237,10 @@ def demo_mode_update():
             demo_mode_next_file()
             return
         # above cycles and minimum display time
-        if  (time_total > global_config["anim_time_min"]) and \
-            (global_state["anim_cycles"] > global_config["anim_cycles"]):
-
+        if (
+                (time_total > global_config["anim_time_min"]) and
+                (global_state["anim_cycles"] > global_config["anim_cycles"])
+        ):
             # looped enough now.
             demo_mode_next_file()
             return
@@ -271,17 +256,18 @@ def demo_mode_update():
         if global_config["anim_screen_switch"]:
             # print(time_delta, 1)
             if time_delta > global_config["anim_screen_switch"]:
-
-                screen = bpy.context.window.screen
-                index = bpy.data.screens.keys().index(screen.name)
-                screen_new = bpy.data.screens[(index if index > 0 else len(bpy.data.screens)) - 1]
-                bpy.context.window.screen = screen_new
+                window = bpy.context.window
+                scene = window.scene
+                workspace = window.workspace
+                index = bpy.data.workspaces.keys().index(workspace.name)
+                workspace_new = bpy.data.workspaces[(index + 1) % len(bpy.data.workspaces)]
+                window.workspace = workspace_new
 
                 global_state["last_switch"] = time_current
 
-                # if we also switch scenes then reset last frame
-                # otherwise it could mess up cycle calc.
-                if screen.scene != screen_new.scene:
+                # If we also switch scenes then reset last frame
+                # otherwise it could mess up cycle calculation.
+                if scene != window.scene:
                     global_state["last_frame"] = -1
 
                 #if global_config["mode"] == 'PLAY':
@@ -404,7 +390,6 @@ class DemoMode(bpy.types.Operator):
         print("func:DemoMode.cancel")
         # disable here means no running on file-load.
         self.cleanup()
-        return {'CANCELLED'}
 
     # call from DemoModeControl
     @classmethod
@@ -419,12 +404,12 @@ class DemoModeControl(bpy.types.Operator):
     bl_idname = "wm.demo_mode_control"
     bl_label = "Control"
 
-    mode = bpy.props.EnumProperty(items=(
-            ('PREV', "Prev", ""),
-            ('PAUSE', "Pause", ""),
-            ('NEXT', "Next", ""),
-            ),
-                name="Mode")
+    mode: bpy.props.EnumProperty(
+        items=(('PREV', "Prev", ""),
+               ('PAUSE', "Pause", ""),
+               ('NEXT', "Next", "")),
+        name="Mode"
+    )
 
     def execute(self, context):
         mode = self.mode
@@ -442,7 +427,7 @@ def menu_func(self, context):
     layout = self.layout
     layout.operator_context = 'EXEC_DEFAULT'
     row = layout.row(align=True)
-    row.label("Demo Mode:")
+    row.label(text="Demo Mode:")
     if not DemoMode.enabled:
         row.operator("wm.demo_mode", icon='PLAY', text="")
     else:
@@ -468,7 +453,7 @@ def unregister():
 
 def load_config(cfg_name=DEMO_CFG):
     namespace = {}
-    global_config_files[:] = []
+    del global_config_files[:]
     basedir = os.path.dirname(bpy.data.filepath)
 
     text = bpy.data.texts.get(cfg_name)
@@ -518,9 +503,8 @@ def load_config(cfg_name=DEMO_CFG):
 
             def blend_dict_items(path):
                 for dirpath, dirnames, filenames in os.walk(path):
-                    # skip '.svn'
-                    if dirpath.startswith("."):
-                        continue
+                    # skip '.git'
+                    dirnames[:] = [d for d in dirnames if not d.startswith(".")]
                     for filename in filenames:
                         if filename.lower().endswith(".blend"):
                             filepath = os.path.join(dirpath, filename)
@@ -528,7 +512,7 @@ def load_config(cfg_name=DEMO_CFG):
 
             blend_lookup.update(dict(blend_dict_items(demo_search_path)))
 
-        # fallback to orginal file
+        # fallback to original file
         return blend_lookup.get(filename, filepath)
     # done with search lookup
 
@@ -539,7 +523,7 @@ def load_config(cfg_name=DEMO_CFG):
         if not os.path.exists(filepath_test):
             filepath_test = lookup_file(filepath_test)  # attempt to get from searchpath
         if not os.path.exists(filepath_test):
-            print("Cant find %r or %r, skipping!")
+            print("Can't find %r or %r, skipping!")
             continue
 
         filecfg["file"] = os.path.normpath(filepath_test)
