@@ -1,22 +1,4 @@
-# ***** BEGIN GPL LICENSE BLOCK *****
-#
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License
-# as published by the Free Software Foundation; either version 2
-# of the License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software Foundation,
-# Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-#
-# ***** END GPL LICENSE BLOCK *****
-
-# <pep8 compliant>
+# SPDX-License-Identifier: GPL-2.0-or-later
 
 # Populate a template file (POT format currently) from Blender RNA/py/C data.
 # XXX: This script is meant to be used from inside Blender!
@@ -224,8 +206,6 @@ def dump_rna_messages(msgs, reports, settings, verbose=False):
             "Context", "Event", "Function", "UILayout", "UnknownType", "Property", "Struct",
             # registerable classes
             "Panel", "Menu", "Header", "RenderEngine", "Operator", "OperatorMacro", "Macro", "KeyingSetInfo",
-            # window classes
-            "Window",
         )
         }
 
@@ -357,7 +337,8 @@ def dump_rna_messages(msgs, reports, settings, verbose=False):
         msgsrc = "bpy.types." + bl_rna.identifier
         msgctxt = bl_rna.translation_context or default_context
 
-        if bl_rna.name and (bl_rna.name != bl_rna.identifier or msgctxt != default_context):
+        if bl_rna.name and (bl_rna.name != bl_rna.identifier or
+                            (msgctxt != default_context and not hasattr(bl_rna, 'bl_label'))):
             process_msg(msgs, msgctxt, bl_rna.name, msgsrc, reports, check_ctxt_rna, settings)
 
         if bl_rna.description:
@@ -378,12 +359,25 @@ def dump_rna_messages(msgs, reports, settings, verbose=False):
 
         walk_properties(cls)
 
+    def walk_keymap_modal_events(keyconfigs, keymap_name, msgsrc_prev, km_i18n_context):
+        for keyconfig in keyconfigs:
+            keymap = keyconfig.keymaps.get(keymap_name, None)
+            if keymap and keymap.is_modal:
+                for modal_event in keymap.modal_event_values:
+                    msgsrc = msgsrc_prev + ":'{}'".format(modal_event.identifier)
+                    if modal_event.name:
+                        process_msg(msgs, km_i18n_context, modal_event.name, msgsrc, reports, None, settings)
+                    if modal_event.description:
+                        process_msg(msgs, default_context, modal_event.description, msgsrc, reports, None, settings)
+
     def walk_keymap_hierarchy(hier, msgsrc_prev):
         km_i18n_context = bpy.app.translations.contexts.id_windowmanager
         for lvl in hier:
             msgsrc = msgsrc_prev + "." + lvl[1]
             if isinstance(lvl[0], str):  # Can be a function too, now, with tool system...
-                process_msg(msgs, km_i18n_context, lvl[0], msgsrc, reports, None, settings)
+                keymap_name = lvl[0]
+                process_msg(msgs, km_i18n_context, keymap_name, msgsrc, reports, None, settings)
+                walk_keymap_modal_events(bpy.data.window_managers[0].keyconfigs, keymap_name, msgsrc, km_i18n_context)
             if lvl[3]:
                 walk_keymap_hierarchy(lvl[3], msgsrc)
 
@@ -440,6 +434,13 @@ def dump_rna_messages(msgs, reports, settings, verbose=False):
             # Recursively process subclasses.
             process_cls_list(cls.__subclasses__())
 
+    # FIXME Workaround weird new (blender 3.2) issue where some classes (like `bpy.types.Modifier`)
+    # are not listed by `bpy.types.ID.__base__.__subclasses__()` until they are accessed from
+    # `bpy.types` (eg just executing `bpy.types.Modifier`).
+    cls_dir = dir(bpy.types)
+    for cls_name in cls_dir:
+        getattr(bpy.types, cls_name)
+
     # Parse everything (recursively parsing from bpy_struct "class"...).
     process_cls_list(bpy.types.ID.__base__.__subclasses__())
 
@@ -813,20 +814,21 @@ def dump_src_messages(msgs, reports, settings):
                 line += data[pos:m.start()].count('\n')
                 msgsrc = rel_path + ":" + str(line)
                 _msgid = d.get("msg_raw")
-                # First, try the "multi-contexts" stuff!
-                _msgctxts = tuple(d.get("ctxt_raw{}".format(i)) for i in range(settings.PYGETTEXT_MAX_MULTI_CTXT))
-                if _msgctxts[0]:
-                    for _msgctxt in _msgctxts:
-                        if not _msgctxt:
-                            break
+                if _msgid not in {'""', "''"}:
+                    # First, try the "multi-contexts" stuff!
+                    _msgctxts = tuple(d.get("ctxt_raw{}".format(i)) for i in range(settings.PYGETTEXT_MAX_MULTI_CTXT))
+                    if _msgctxts[0]:
+                        for _msgctxt in _msgctxts:
+                            if not _msgctxt:
+                                break
+                            msgctxt, msgid = process_entry(_msgctxt, _msgid)
+                            process_msg(msgs, msgctxt, msgid, msgsrc, reports, check_ctxt_src, settings)
+                            reports["src_messages"].append((msgctxt, msgid, msgsrc))
+                    else:
+                        _msgctxt = d.get("ctxt_raw")
                         msgctxt, msgid = process_entry(_msgctxt, _msgid)
                         process_msg(msgs, msgctxt, msgid, msgsrc, reports, check_ctxt_src, settings)
                         reports["src_messages"].append((msgctxt, msgid, msgsrc))
-                else:
-                    _msgctxt = d.get("ctxt_raw")
-                    msgctxt, msgid = process_entry(_msgctxt, _msgid)
-                    process_msg(msgs, msgctxt, msgid, msgsrc, reports, check_ctxt_src, settings)
-                    reports["src_messages"].append((msgctxt, msgid, msgsrc))
 
                 pos = m.end()
                 line += data[m.start():pos].count('\n')
@@ -862,6 +864,25 @@ def dump_src_messages(msgs, reports, settings):
             dump_src_file(path, rel_path, msgs, reports, settings)
 
 
+def dump_preset_messages(msgs, reports, settings):
+    files = []
+    for dpath, _, fnames in os.walk(settings.PRESETS_DIR):
+        for fname in fnames:
+            if fname.startswith("_") or not fname.endswith(".py"):
+                continue
+            path = os.path.join(dpath, fname)
+            try:  # can't always find the relative path (between drive letters on windows)
+                rel_path = os.path.relpath(path, settings.PRESETS_DIR)
+            except ValueError:
+                rel_path = path
+            files.append(rel_path)
+    for rel_path in sorted(files):
+        msgsrc, msgid = os.path.split(rel_path)
+        msgsrc = "Preset from " + msgsrc
+        msgid = bpy.path.display_name(msgid, title_case=False)
+        process_msg(msgs, settings.DEFAULT_CONTEXT, msgid, msgsrc, reports, None, settings)
+
+
 ##### Main functions! #####
 def dump_messages(do_messages, do_checks, settings):
     bl_ver = "Blender " + bpy.app.version_string
@@ -877,7 +898,7 @@ def dump_messages(do_messages, do_checks, settings):
     addons = utils.enable_addons(support={"OFFICIAL"})
     # Note this is not needed if we have been started with factory settings, but just in case...
     # XXX This is not working well, spent a whole day trying to understand *why* we still have references of
-    #     those removed calsses in things like `bpy.types.OperatorProperties.__subclasses__()`
+    #     those removed classes in things like `bpy.types.OperatorProperties.__subclasses__()`
     #     (could not even reproduce it from regular py console in Blender with UI...).
     #     For some reasons, cleanup does not happen properly, *and* we have no way to tell which class is valid
     #     and which has been unregistered. So for now, just go for the dirty, easy way: do not disable add-ons. :(
@@ -894,6 +915,9 @@ def dump_messages(do_messages, do_checks, settings):
     # Get strings from C source code.
     dump_src_messages(msgs, reports, settings)
 
+    # Get strings from presets.
+    dump_preset_messages(msgs, reports, settings)
+
     # Get strings from addons' categories.
     for uid, label, tip in bpy.types.WindowManager.addon_filter.keywords['items'](
             bpy.context.window_manager,
@@ -971,7 +995,12 @@ def dump_addon_messages(module_name, do_checks, settings):
     # and make the diff!
     for key in minus_msgs:
         if key != settings.PO_HEADER_KEY:
-            del msgs[key]
+            if key in msgs:
+                del msgs[key]
+            else:
+                # This should not happen, but some messages seem to have
+                # leaked on add-on unregister and register?
+                print(f"Key not found in msgs: {key}")
 
     if check_ctxt:
         _diff_check_ctxt(check_ctxt, minus_check_ctxt)
