@@ -1,22 +1,4 @@
-# ##### BEGIN GPL LICENSE BLOCK #####
-#
-#  This program is free software; you can redistribute it and/or
-#  modify it under the terms of the GNU General Public License
-#  as published by the Free Software Foundation; either version 2
-#  of the License, or (at your option) any later version.
-#
-#  This program is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with this program; if not, write to the Free Software Foundation,
-#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-#
-# ##### END GPL LICENSE BLOCK #####
-
-# <pep8 compliant>
+# SPDX-License-Identifier: GPL-2.0-or-later
 import bpy
 from bpy.types import Operator
 from bpy.props import FloatProperty
@@ -123,8 +105,8 @@ def CLIP_default_settings_from_track(clip, track, framenr):
     search[1] = search[1] * height
 
     settings.default_correlation_min = track.correlation_min
-    settings.default_pattern_size = max(pattern[0], pattern[1])
-    settings.default_search_size = max(search[0], search[1])
+    settings.default_pattern_size = int(max(pattern[0], pattern[1]))
+    settings.default_search_size = int(max(search[0], search[1]))
     settings.default_frames_limit = track.frames_limit
     settings.default_pattern_match = track.pattern_match
     settings.default_margin = track.margin
@@ -949,7 +931,7 @@ class CLIP_OT_setup_tracking_scene(Operator):
             """Make all the newly created and the old objects of a collection """ \
                 """to be properly setup for shadow catch"""
             for ob in collection.objects:
-                ob.cycles.is_shadow_catcher = True
+                ob.is_shadow_catcher = True
                 for child in collection.children:
                     setup_shadow_catcher_objects(child)
 
