@@ -1,22 +1,4 @@
-# ##### BEGIN GPL LICENSE BLOCK #####
-#
-#  This program is free software; you can redistribute it and/or
-#  modify it under the terms of the GNU General Public License
-#  as published by the Free Software Foundation; either version 2
-#  of the License, or (at your option) any later version.
-#
-#  This program is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with this program; if not, write to the Free Software Foundation,
-#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-#
-# ##### END GPL LICENSE BLOCK #####
-
-# <pep8-80 compliant>
+# SPDX-License-Identifier: GPL-2.0-or-later
 
 import bpy
 from bpy.types import Operator
@@ -133,7 +115,7 @@ class SelectCamera(Operator):
         scene = context.scene
         view_layer = context.view_layer
         view = context.space_data
-        if view.type == 'VIEW_3D' and view.use_local_camera:
+        if view and view.type == 'VIEW_3D' and view.use_local_camera:
             camera = view.camera
         else:
             camera = scene.camera
@@ -614,6 +596,8 @@ class MakeDupliFace(Operator):
         for obj in context.selected_objects:
             if obj.type == 'MESH':
                 linked[obj.data].append(obj)
+            elif obj.type == 'EMPTY' and obj.instance_type == 'COLLECTION' and obj.instance_collection:
+                linked[obj.instance_collection].append(obj)
 
         for data, objects in linked.items():
             face_verts = [axis for obj in objects
@@ -639,7 +623,12 @@ class MakeDupliFace(Operator):
             ob_new = bpy.data.objects.new(mesh.name, mesh)
             context.collection.objects.link(ob_new)
 
-            ob_inst = bpy.data.objects.new(data.name, data)
+            if type(data) is bpy.types.Collection:
+                ob_inst = bpy.data.objects.new(data.name, None)
+                ob_inst.instance_type = 'COLLECTION'
+                ob_inst.instance_collection = data
+            else:
+                ob_inst = bpy.data.objects.new(data.name, data)
             context.collection.objects.link(ob_inst)
 
             ob_new.instance_type = 'FACES'
@@ -864,10 +853,6 @@ class DupliOffsetFromCursor(Operator):
     bl_label = "Set Offset from Cursor"
     bl_options = {'INTERNAL', 'UNDO'}
 
-    @classmethod
-    def poll(cls, context):
-        return (context.active_object is not None)
-
     def execute(self, context):
         scene = context.scene
         collection = context.collection
@@ -877,6 +862,37 @@ class DupliOffsetFromCursor(Operator):
         return {'FINISHED'}
 
 
+class DupliOffsetToCursor(Operator):
+    """Set cursor position to the offset used for collection instances"""
+    bl_idname = "object.instance_offset_to_cursor"
+    bl_label = "Set Cursor to Offset"
+    bl_options = {'INTERNAL', 'UNDO'}
+
+    def execute(self, context):
+        scene = context.scene
+        collection = context.collection
+        scene.cursor.location = collection.instance_offset
+        return {'FINISHED'}
+
+
+class DupliOffsetFromObject(Operator):
+    """Set offset used for collection instances based on the active object position"""
+    bl_idname = "object.instance_offset_from_object"
+    bl_label = "Set Offset from Object"
+    bl_options = {'INTERNAL', 'UNDO'}
+
+    @classmethod
+    def poll(cls, context):
+        return (context.active_object is not None)
+
+    def execute(self, context):
+        ob_eval = context.active_object.evaluated_get(context.view_layer.depsgraph)
+        world_loc = ob_eval.matrix_world.to_translation()
+        collection = context.collection
+        collection.instance_offset = world_loc
+        return {'FINISHED'}
+
+
 class LoadImageAsEmpty:
     bl_options = {'REGISTER', 'UNDO'}
 
@@ -953,7 +969,7 @@ class LoadReferenceImage(LoadImageAsEmpty, Operator):
 
 class OBJECT_OT_assign_property_defaults(Operator):
     """Assign the current values of custom properties as their defaults, """ \
-    """for use as part of the rest pose state in NLA track mixing"""
+        """for use as part of the rest pose state in NLA track mixing"""
     bl_idname = "object.assign_property_defaults"
     bl_label = "Assign Custom Property Values as Default"
     bl_options = {'UNDO', 'REGISTER'}
@@ -970,7 +986,7 @@ class OBJECT_OT_assign_property_defaults(Operator):
     def assign_defaults(obj):
         from rna_prop_ui import rna_idprop_ui_prop_default_set
 
-        rna_properties = {'_RNA_UI'} | {prop.identifier for prop in obj.bl_rna.properties if prop.is_runtime}
+        rna_properties = {prop.identifier for prop in obj.bl_rna.properties if prop.is_runtime}
 
         for prop, value in obj.items():
             if prop not in rna_properties:
@@ -998,6 +1014,8 @@ class OBJECT_OT_assign_property_defaults(Operator):
 classes = (
     ClearAllRestrictRender,
     DupliOffsetFromCursor,
+    DupliOffsetToCursor,
+    DupliOffsetFromObject,
     IsolateTypeRender,
     JoinUVs,
     LoadBackgroundImage,
